@@ -53,7 +53,7 @@ QString randomPlatform()
 {
     static const QStringList hostNames = {QStringLiteral("Linux 2.6"), QStringLiteral("Linux 3.2"), QStringLiteral("Linux 3.6")};
     return hostNames[qrand() % hostNames.size()];
-};
+}
 }
 
 FakeMonitor::FakeMonitor(HostInfoManager *manager, QObject *parent)
@@ -81,6 +81,7 @@ void FakeMonitor::createHostInfo(HostId id)
     info.setName(HOST_NAMES[id % HOST_NAMES.length()] + QString::number(id));
     info.setColor(info.createColor(info.name()));
     info.setOffline(false);
+    info.setNoRemote(false);
     info.setPlatform(randomPlatform());
     info.setServerLoad(1.0);
     info.setServerSpeed(10);
