@@ -42,8 +42,8 @@ class MainWindow
     Q_OBJECT
 
 public:
-    MainWindow(QWidget *parent = nullptr);
-    virtual ~MainWindow();
+    explicit MainWindow(QWidget *parent = nullptr);
+    ~MainWindow() override;
 
     void setCurrentNet(const QByteArray &netname);
     void setCurrentSched(const QByteArray &schedname);
