@@ -48,8 +48,8 @@ public:
     };
     Q_DECLARE_FLAGS(Options, Option)
 
-    StatusView(QObject *parent = nullptr);
-    virtual ~StatusView();
+    explicit StatusView(QObject *parent = nullptr);
+    ~StatusView() override;
 
     virtual Options options() const;
 
