@@ -81,13 +81,13 @@ class SummaryView
     Q_OBJECT
 
 public:
-    SummaryView(QObject *parent = nullptr);
-    ~SummaryView();
+    explicit SummaryView(QObject *parent = nullptr);
+    ~SummaryView() override;
 
-    virtual QWidget *widget() const override;
-    virtual void update(const Job &job) override;
-    virtual void checkNode(unsigned int hostid) override;
-    virtual QString id() const override { return QStringLiteral("summary"); }
+    QWidget *widget() const override;
+    void update(const Job &job) override;
+    void checkNode(unsigned int hostid) override;
+    QString id() const override { return QStringLiteral("summary"); }
 
 private:
     QScopedPointer<SummaryViewScrollArea> m_widget;
